==> spread-5.2.0.24-py3-none-any.whl: spread_dashboard/apps.py <==
import json
import logging
import os
import sys

import paho.mqtt.client
from django.apps import AppConfig

from spread_core.tools import reset
from spread_core import mqtt
import spread_core.tools.settings_const as S


class DashboardConfig(AppConfig):
    name = 'spread_dashboard'

    settings = None
    project = None
    project_id = 0
    restarted = False

    def ready(self):
        super(DashboardConfig, self).ready()
        if 'daphne' in sys.argv[0] or 'runserver' in sys.argv:
            import spread_dashboard.project.bam as bam

            self.project = bam.Project()
            self.settings = bam.Settings()
            self.publish_web_token()

    @property
    def has_project(self): return self.project_id != 0

    def publish_web_token(self):
        if self.has_project:
            try:
                from spread_dashboard import auth2
                client = paho.mqtt.client.Client(userdata="WebTokenPublisher")
                client.username_pw_set(self.settings[S.BROKER][S.LOGIN], self.settings[S.BROKER][S.PASSWORD])
                client.connect(self.settings[S.BROKER][S.HOST], self.settings[S.BROKER][S.PORT])
                client.publish(mqtt.dashboard.web_token(self.project_id), auth2.get_token(), retain=True)
                client.disconnect()
            except BaseException as ex:
                logging.exception(ex)

    @property
    def static_settings(self):
        try:
            with open(os.environ.get('SETTINGS')) as fs:
                return json.load(fs)
        except BaseException:
            reset.configure_dashboard()
            return reset.DASHBOARD_STATIC

==> spread-5.3.0.5-py3-none-any.whl: spread_dashboard/apps.py <==
import json
import logging
import os
import sys

import paho.mqtt.client
from django.apps import AppConfig

from spread_core.tools import reset
from spread_core import mqtt
import spread_core.tools.settings_const as S


class DashboardConfig(AppConfig):
    name = 'spread_dashboard'

    settings = None
    project = None
    project_id = 0
    restarted = False

    def ready(self):
        super(DashboardConfig, self).ready()
        if 'daphne' in sys.argv[0] or 'runserver' in sys.argv:
            import spread_dashboard.project.bam as bam

            self.project = bam.Project()
            self.settings = bam.Settings()
            self.publish_web_token()

    @property
    def has_project(self): return self.project_id != 0

    def publish_web_token(self):
        if self.has_project:
            try:
                from spread_dashboard import auth2
                client = paho.mqtt.client.Client(userdata="WebTokenPublisher")
                client.username_pw_set(self.settings[S.BROKER][S.LOGIN], self.settings[S.BROKER][S.PASSWORD])
                client.connect(self.settings[S.BROKER][S.HOST], self.settings[S.BROKER][S.PORT])
                client.publish(mqtt.dashboard.WEB_TOKEN, auth2.get_token(), retain=True)
                client.disconnect()
            except BaseException as ex:
                logging.exception(ex)

    @property
    def static_settings(self):
        try:
            with open(os.environ.get('SETTINGS')) as fs:
                return json.load(fs)
        except BaseException:
            reset.configure_dashboard()
            return reset.DASHBOARD_STATIC
